@@ -10,7 +10,7 @@ use namespace::autoclean;
 
 requires 'method';
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 
 foreach my $name (qw/ get head post put delete connect options trace patch /) {
@@ -27,6 +27,7 @@ foreach my $name (qw/ get head post put delete connect options trace patch /) {
 
 }
 
+
 1;
 
 __END__
@@ -41,7 +42,7 @@ Catalyst::TraitFor::Request::Methods - Add enumerated methods for HTTP requests
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -67,6 +68,14 @@ checking the HTTP request method.
 Using these methods is a less error-prone alternative to checking a
 case-sensitive string with the method name.
 
+In other words, you can use
+
+  $c->request->is_get
+
+instead of
+
+  $c->request->method eq "GET"
+
 =head1 METHODS
 
 =head2 is_get
@@ -105,6 +114,10 @@ The request method is C<TRACE>.
 
 The request method is C<PATCH>.
 
+=head1 SEE ALSO
+
+L<Catalyst::Request>
+
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/Catalyst-TraitFor-Request-Methods->
